@@ -13,13 +13,15 @@ from .client import remote  # noqa: E402
 from .core.resources import (  # noqa: E402
     CpuServerlessEndpoint,
     CpuInstanceType,
+    CpuLiveServerless,
     CudaVersion,
+    DataCenter,
     GpuGroup,
     LiveServerless,
     PodTemplate,
     ResourceManager,
     ServerlessEndpoint,
-    runpod,
+    ServerlessType,
     NetworkVolume,
 )
 
@@ -28,12 +30,14 @@ __all__ = [
     "remote",
     "CpuServerlessEndpoint",
     "CpuInstanceType",
+    "CpuLiveServerless",
     "CudaVersion",
+    "DataCenter",
     "GpuGroup",
     "LiveServerless",
     "PodTemplate",
     "ResourceManager",
     "ServerlessEndpoint",
-    "runpod",
+    "ServerlessType",
     "NetworkVolume",
 ]
